@@ -30,9 +30,7 @@ The following methods can be used
 
    my $bbc = HTML::BBCode->new({
       allowed_tags => [ @bbcode_tags ],
-      html_tags    => \%html_tags,
-      no_html      => 1,
-      no_jslink    => 1,
+      stripscripts => 1,
       linebreaks   => 1,
    });
 
@@ -50,23 +48,18 @@ Defaults to all currently know C<BBCode tags>, being:
 b, u, i, color, size, quote, code, list, url, email, img. With this
 option, you can specify what BBCode tags you would like to convert.
 
-=item html_tags
+=item stripscripts
 
-Configures the wanted output in HTML. Defaults to (almost) the same as
-used on the phpbb bulletin boards (<b>, <u> etc. have been turned into
-their CSS equivalents).
+Enabled by default, this option will remove all the XSS trickery (and
+thus is probably best not to turn it off).
 
 =item no_html
 
-Disabled by default.
-
-When true, HTML tags will be converted from '<br />' to '&lt;br /&gt;'
+This option has been removed since version 2.0
 
 =item no_jslink
 
-Enabled by default.
-
-When true, links like C<javascript:foo(bar)> will be disabled.
+This option has been removed since version 2.0
 
 =item linebreaks
 
@@ -83,6 +76,13 @@ When true, will substitute linebreaks into HTML ('<br />')
 Parses text supplied as a single scalar string and returns the HTML as
 a single scalar string.
 
+=head1 CAVEAT: API CHANGES
+
+Please do note that the C<html_tags>, C<no_html>, C<no_jslink> options in 
+the new method have been removed since version 2.0 due to the XSS protection 
+(provided by L<HTML::StripScripts::Parser>). This will most likely 
+break your current scripts (if you used the C<html_tags> option).
+
 =head1 SEE ALSO
 
 =over 4
@@ -91,7 +91,7 @@ a single scalar string.
 
 =item * L<http://menno.b10m.net/perl/>
 
-=item * L<HTML::BBReverse>, L<BBCode::Parser>
+=item * L<HTML::StripScripts::Parser>, L<HTML::BBReverse>, L<BBCode::Parser>
 
 =back
 
@@ -105,7 +105,7 @@ M. Blom, E<lt>blom@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004,2005,2006 by M. Blom
+Copyright (C) 2004,2005,2006,2007 by M. Blom
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -114,8 +114,9 @@ it under the same terms as Perl itself.
 #------------------------------------------------------------------------------#
 use strict;
 use warnings;
+use HTML::BBCode::StripScripts;
 
-our $VERSION = '1.06';
+our $VERSION = '2.00';
 our @bbcode_tags = qw(code quote b u i color size list url email img);
 
 sub new {
@@ -138,28 +139,71 @@ sub _init {
                    '<div class="bbcode_code_body">%s</div>',
      quote      => '<div class="bbcode_quote_header">%s</div>'.
                    '<div class="bbcode_quote_body">%s</div>',
-     b          => '<span style="font-weight: bold">%s</span>',
-     u          => '<span style="text-decoration: underline;">%s</span>',
-     i          => '<span style="font-style: italic">%s</span>',
-     color      => '<span style="color: %s">%s</span>',
-     size       => '<span style="font-size: %spx">%s</span>',
+     b          => '<span style="font-weight:bold">%s</span>',
+     u          => '<span style="text-decoration:underline;">%s</span>',
+     i          => '<span style="font-style:italic">%s</span>',
+     color      => '<span style="color:%s">%s</span>',
+     size       => '<span style="font-size:%spx">%s</span>',
      url        => '<a href="%s">%s</a>',
      email      => '<a href="mailto:%s">%s</a>',
      img        => '<img src="%s" alt="" />',
      ul         => '<ul>%s</ul>',
      ol_number  => '<ol>%s</ol>',
-     ol_alpha   => '<ol style="list-style-type: lower-alpha;">%s</ol>',
+     ol_alpha   => '<ol style="list-style-type:lower-alpha;">%s</ol>',
    );
 
    my %options = (
 		  allowed_tags=> \@bbcode_tags,
 		  html_tags    => \%html_tags,
-		  no_html      => 0,
-		  no_jslink    => 1,
+		  stripscripts => 1,
 		  linebreaks   => 0,
  		  %{ $args },
 		);
    $self->{options} = \%options;
+
+   $self->{'hss'} = HTML::BBCode::StripScripts->new({
+      Context        => 'Flow',
+      AllowSrc       => 1,
+      AllowMailto    => 1,
+      AllowHref      => 1,
+      AllowRelURL    => 1,
+      EscapeFiltered => 1,
+      BanAllBut      => [qr/a div img li ol span ul/],
+      Rules          => {
+         br  => 1,
+         img => {
+            required  => ['src'],
+            'src'     => 1,
+            'alt'     => 1,
+            '*'       => 0,
+         },
+         a   => {
+            required  => ['href'],
+            'href'    => 1,
+            '*'       => 0,
+         },
+         img => { 
+            'src'     => 1,
+            'alt'     => 1,
+            '*'       => 0,
+         },
+         div => {
+            class => qr{^bbcode_},
+            '*'   => 0,
+         },
+         span => {
+            style => \&_filter_style,
+            '*'   => 0,
+         },
+         ol => {
+            style => qr/^list-style-type:lower-alpha$/,
+            '*'   => 0,
+         },
+         ul => 1,
+         li => 1,
+      }
+   });
+
    return $self;
 }
 
@@ -222,7 +266,8 @@ sub parse {
       }
    }
    $self->{html} = join('', @{$self->{_stack}});
-   return $self->{html};
+print $self->{html},"\n\n\n";
+   return $self->{options}->{stripscripts} ? $self->_stripscripts() : $self->{html};
 }
 
 sub _open_tag {
@@ -242,10 +287,6 @@ sub _open_tag {
 
 sub _content {
    my ($self, $content) = @_;
-   if($self->{options}->{no_html}) {
-      $content =~ s|<|&lt;|gs;
-      $content =~ s|>|&gt;|gs;
-   }
    $content =~ s|\r*||gs;
    $content =~ s|\n|<br />\n|gs if($self->{options}->{linebreaks} &&
    			           $self->{_in_code_block} == 0);
@@ -319,10 +360,6 @@ sub _do_BB {
    if($open =~ /\[([^=\]]+)=?([^\]]+)?]/) {
       $tag  = $1;
       $attr = $2;
-      if($attr && $self->{options}->{no_html}) {
-         $attr =~ s|<|&lt;|gs;
-         $attr =~ s|>|&gt;|gs;
-      }
    }
 
    # Kludgy way to handle specific BBCodes ... 
@@ -337,13 +374,10 @@ sub _do_BB {
    } elsif($tag eq 'list') {
      $html = _list($self, $attr, $content);
    } elsif(($tag eq 'email' || $tag eq 'url') && !$attr) {
-      $content =~ s|javascript:||g if($self->{options}->{no_jslink});
       $html = sprintf($self->{options}->{html_tags}->{$tag}, $content,$content);
    } elsif ($attr) {
-      $attr =~ s|javascript:||g if($self->{options}->{no_jslink});
       $html = sprintf($self->{options}->{html_tags}->{$tag}, $attr, $content);
    } else {
-      $content =~ s|javascript:||g if($self->{options}->{no_jslink});
       $html = sprintf($self->{options}->{html_tags}->{$tag}, $content);
    }
    # Return ...
@@ -401,11 +435,40 @@ sub _list_removelastbr {
    return "<li>$content</li>\n";
 }
 
+sub _stripscripts {
+   my $self = shift;
+   $self->{'html'} = $self->{'hss'}->filter_html($self->{'html'});
+   return $self->{'html'};
+}
+
+sub _filter_style {
+   my ($filter, $tag, $attr_name, $attr_val) = @_;
+   if ($attr_val eq 'font-weight:bold'
+       or $attr_val eq 'text-decoration:underline'
+       or $attr_val eq 'font-style:italic'
+       or $attr_val eq 'list-style-type') {
+        return $attr_val;
+   }
+   if ( my ($color) = $attr_val =~ /^color:(.*)/ ) {
+        my @html_color = qw/
+          black gray maroon red green lime olive yellow
+          navy blue purple fuchsia teal aqua silver white
+          /;
+      return $attr_val if $color =~ /^#[a-fA-F\d]{6}$/;
+      return $attr_val if $color =~ /^#[a-fA-F\d]{3}$/;
+      return $attr_val if grep { $color eq $_ } @html_color;
+      return undef;
+   }
+   if ( $attr_val =~ /font-size:\d+px/ ) {
+      return $attr_val;
+   }
+   return undef;
+}
+
 sub _croak {
     my ($class, @error) = @_;
     require Carp;
     Carp::croak(@error);
 }
 
-
 1;
